@@ -15,6 +15,7 @@ class Runtime:
         self.operation_id = operation_id
         self.memory = kwargs.get('memory')
         self.cpu = kwargs.get('cpu')
+        self.env = kwargs.get('env')
 
     @property
     def command_build(self) -> str:
@@ -23,9 +24,17 @@ class Runtime:
     @property
     def command_create(self) -> str:
         name = self.operation_id.replace('_', '-')
+
+        env = ""
+        if self.env is not None:
+            env_vars = ",".join(self.env)
+            env = f"--set-env-vars {env_vars}"
+        else:
+            env = "--set-env-vars ENV='production'"
+
         return " ".join([
             f"gcloud beta run jobs create {name}"
-            f" --image='gcr.io/{self.config.gcp_project}/{self.operation_id}' --tasks 1 --set-env-vars ENV='production'"
+            f" --image='gcr.io/{self.config.gcp_project}/{self.operation_id}' --tasks 1 {env}"
             f" --max-retries 3 --region={self.config.gcp_region} --project={self.config.gcp_project}",
             "" if self.memory is None else f"--memory={self.memory}",
             "" if self.cpu is None else f"--cpu={self.cpu}",
@@ -41,21 +50,32 @@ class Runtime:
         name = self.operation_id.replace('_', '-')
         return f"gcloud beta run jobs execute {name} --region='{self.config.gcp_region}' --project='{self.config.gcp_project}'"
 
+    @property
+    def secrethub_env(self) -> str:
+        return "secrethub inject -i .env.temp -o .env"
+
 
 class Job:
     def __init__(self, operation_id: str, **kwargs):
         self.operation_id = operation_id
 
     def runtime(self, config: Config) -> Runtime:
-        path = f'{config.base_dir}/jobs/config.yaml'
-
-        if Path(path).exists():
-            with open(path) as f:
+        config_path = f'{config.base_dir}/jobs/config.yaml'
+        if Path(config_path).exists():
+            with open(config_path) as f:
                 runtime_config = yaml.safe_load(f.read())
         else:
             runtime_config = {}
 
-        return Runtime(config, self.operation_id, **runtime_config)
+        env_path = f'{config.base_dir}/jobs/{self.operation_id}/.env'
+        if Path(env_path).exists():
+            with open(env_path) as f:
+                env_data = f.read().split('\n')
+        else:
+            env_data = None
+
+        print('ENV Data', env_data)
+        return Runtime(config, self.operation_id, env=env_data, **runtime_config)
 
 
 def job_list(config: Config) -> List[Job]:
@@ -129,6 +149,12 @@ def cli_main(args, config: Config):
                 f'{config.base_dir}/jobs/{job_name}/requirements.txt',
                 "",
             ),
+            steps.StepCreateFile(
+                f'{config.base_dir}/jobs/{job_name}/.env.temp',
+                "ENV=production",
+            ),
+            # gitignore
+            # cloudignore
         ]
         manager = steps.Manager(config, commands, simulate=args.simulate)
         rc = manager.run()
@@ -161,12 +187,16 @@ def cli_main(args, config: Config):
         print('# Deploy')
         job = jobs[0]
         runtime = job.runtime(config)
-        commands = [
+        commands = [x for x in [
             # delete job if exists?
             steps.StepCommand(
                 shlex.split(runtime.command_build),
                 work_dir=f'{config.base_dir}/jobs/{job_name}',
             ),
+            None if not Path(f'{config.base_dir}/jobs/{job_name}/.env.temp').exists() else steps.StepCommand(
+                shlex.split(runtime.secrethub_env),
+                work_dir=f'{config.base_dir}/jobs/{job_name}',
+            ),
             steps.StepCommand(
                 shlex.split(runtime.command_delete),
                 work_dir=f'{config.base_dir}/jobs/{job_name}',
@@ -176,7 +206,7 @@ def cli_main(args, config: Config):
                 shlex.split(runtime.command_create),
                 work_dir=f'{config.base_dir}/jobs/{job_name}',
             ),
-        ]
+        ] if x is not None]
         manager = steps.Manager(config, commands, simulate=args.simulate)
         rc = manager.run()
         if rc != 0:
